@@ -1,12 +1,14 @@
-use crate::api::{ErrorApi, StorageReadApi, StorageWriteApi};
-use crate::types::BoxedBytes;
+use crate::{
+    api::{ErrorApi, ManagedTypeApi, StorageReadApi, StorageWriteApi},
+    storage::StorageKey,
+};
 
 pub trait StorageMapper<SA>: 'static
 where
-    SA: StorageReadApi + StorageWriteApi + ErrorApi + Clone + 'static,
+    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
 {
     /// Will be called automatically by the `#[storage_mapper]` annotation generated code.
-    fn new(api: SA, key: BoxedBytes) -> Self;
+    fn new(api: SA, base_key: StorageKey<SA>) -> Self;
 }
 
 pub trait StorageClearable {
