@@ -1,32 +1,33 @@
 use super::StorageMapper;
-use crate::abi::{TypeAbi, TypeDescriptionContainer, TypeName};
-use crate::api::{EndpointFinishApi, ErrorApi, StorageReadApi, StorageWriteApi};
-use crate::io::EndpointResult;
-use crate::storage::{storage_get, storage_set};
-use crate::types::BoxedBytes;
+use crate::{
+    abi::{TypeAbi, TypeDescriptionContainer, TypeName},
+    api::{EndpointFinishApi, ErrorApi, ManagedTypeApi, StorageReadApi, StorageWriteApi},
+    io::EndpointResult,
+    storage::{storage_clear, storage_get, storage_get_len, storage_set, StorageKey},
+};
 use core::marker::PhantomData;
 use elrond_codec::{TopDecode, TopEncode};
 
 /// Manages a single serializable item in storage.
 pub struct SingleValueMapper<SA, T>
 where
-    SA: StorageReadApi + StorageWriteApi + ErrorApi + Clone + 'static,
+    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
     T: TopEncode + TopDecode + 'static,
 {
     api: SA,
-    key: BoxedBytes,
+    key: StorageKey<SA>,
     _phantom: core::marker::PhantomData<T>,
 }
 
 impl<SA, T> StorageMapper<SA> for SingleValueMapper<SA, T>
 where
-    SA: StorageReadApi + StorageWriteApi + ErrorApi + Clone + 'static,
+    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
     T: TopEncode + TopDecode,
 {
-    fn new(api: SA, key: BoxedBytes) -> Self {
+    fn new(api: SA, base_key: StorageKey<SA>) -> Self {
         SingleValueMapper {
             api,
-            key,
+            key: base_key,
             _phantom: PhantomData,
         }
     }
@@ -34,12 +35,12 @@ where
 
 impl<SA, T> SingleValueMapper<SA, T>
 where
-    SA: StorageReadApi + StorageWriteApi + ErrorApi + Clone + 'static,
+    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
     T: TopEncode + TopDecode,
 {
     /// Retrieves current value from storage.
     pub fn get(&self) -> T {
-        storage_get(self.api.clone(), self.key.as_slice())
+        storage_get(self.api.clone(), &self.key)
     }
 
     /// Returns whether the storage managed by this mapper is empty.
@@ -49,7 +50,7 @@ where
 
     /// Saves argument to storage.
     pub fn set(&self, new_value: &T) {
-        storage_set(self.api.clone(), self.key.as_slice(), new_value);
+        storage_set(self.api.clone(), &self.key, new_value);
     }
 
     /// Saves argument to storage only if the storage is empty.
@@ -62,7 +63,7 @@ where
 
     /// Clears the storage for this mapper.
     pub fn clear(&self) {
-        self.api.storage_store_slice_u8(self.key.as_slice(), &[]);
+        storage_clear(self.api.clone(), &self.key);
     }
 
     /// Syntactic sugar, to more compactly express a get, update and set in one line.
@@ -76,20 +77,20 @@ where
     }
 
     pub fn raw_byte_length(&self) -> usize {
-        self.api.storage_load_len(self.key.as_slice())
+        storage_get_len(self.api.clone(), &self.key)
     }
 }
 
 impl<SA, T> EndpointResult for SingleValueMapper<SA, T>
 where
-    SA: StorageReadApi + StorageWriteApi + ErrorApi + Clone + 'static,
+    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
     T: TopEncode + TopDecode + EndpointResult,
 {
     type DecodeAs = T::DecodeAs;
 
     fn finish<FA>(&self, api: FA)
     where
-        FA: EndpointFinishApi + Clone + 'static,
+        FA: ManagedTypeApi + EndpointFinishApi + Clone + 'static,
     {
         self.get().finish(api);
     }
@@ -97,7 +98,7 @@ where
 
 impl<SA, T> TypeAbi for SingleValueMapper<SA, T>
 where
-    SA: StorageReadApi + StorageWriteApi + ErrorApi + Clone + 'static,
+    SA: StorageReadApi + StorageWriteApi + ManagedTypeApi + ErrorApi + Clone + 'static,
     T: TopEncode + TopDecode + TypeAbi,
 {
     fn type_name() -> TypeName {
