@@ -29,7 +29,7 @@ where
         let mbuf_handle = self
             .api
             .storage_load_managed_buffer_raw(self.key.buffer.get_raw_handle());
-        ManagedBuffer::from_raw_handle(self.api.clone(), mbuf_handle)
+        ManagedBuffer::from_raw_handle(mbuf_handle)
     }
 
     fn to_big_uint(&self) -> BigUint<A> {
@@ -124,8 +124,7 @@ fn storage_get_exit<A>(api: A, de_err: DecodeError) -> !
 where
     A: StorageReadApi + ManagedTypeApi + ErrorApi + 'static,
 {
-    let mut message_buffer =
-        ManagedBuffer::new_from_bytes(api.clone(), err_msg::STORAGE_DECODE_ERROR);
+    let mut message_buffer = ManagedBuffer::<A>::new_from_bytes(err_msg::STORAGE_DECODE_ERROR);
     message_buffer.append_bytes(de_err.message_bytes());
     api.signal_error_from_buffer(message_buffer.get_raw_handle())
 }
