@@ -30,13 +30,13 @@ impl<M: ManagedTypeApi> EsdtTokenPaymentMultiArg<M> {
     }
 }
 
-impl<M: ManagedTypeApi> ManagedVecItem<M> for EsdtTokenPaymentMultiArg<M> {
+impl<M: ManagedTypeApi> ManagedVecItem for EsdtTokenPaymentMultiArg<M> {
     const PAYLOAD_SIZE: usize = EsdtTokenPayment::<M>::PAYLOAD_SIZE;
     const SKIPS_RESERIALIZATION: bool = EsdtTokenPayment::<M>::SKIPS_RESERIALIZATION;
 
     #[inline]
-    fn from_byte_reader<Reader: FnMut(&mut [u8])>(api: M, reader: Reader) -> Self {
-        EsdtTokenPayment::from_byte_reader(api, reader).into()
+    fn from_byte_reader<Reader: FnMut(&mut [u8])>(reader: Reader) -> Self {
+        EsdtTokenPayment::from_byte_reader(reader).into()
     }
 
     #[inline]
